@@ -170,19 +170,23 @@ add_species_arrows = function(radius = 5.0, label = "Species", reverse = TRUE, s
 #'  \code{"frequency"} \tab the number of sites where they occur \cr
 #'  \code{"main environmental effect"} \tab their most important environmental coefficients \cr}
 #' @param species_indices indices for sorting species
-#' @details  After fitting the jSDM with latent variables, the \bold{fullspecies residual correlation matrix} : \eqn{R=(R_ij) avec i=1,\ldots, nspecies et j=1,\ldots, nspecies}{R=(R_ij) avec i=1,..., nspecies et j=1,..., nspecies}
+#' @details  After fitting the jSDM with latent variables, the \bold{fullspecies residual correlation matrix} : \eqn{R=(R_{ij})}{R=(R_ij)} with \eqn{i=1,\ldots, n_{species}}{i=1,..., n_species} and \eqn{j=1,\ldots, n_{species}}{j=1,..., n_species} can be derived from the covariance in the latent variables such as : 
 #'  can be derived from the covariance in the latent variables such as : 
 #' \tabular{lll}{
 #' \eqn{\Sigma_{ij}}{Sigma_ij} \tab \eqn{= \lambda_i .\lambda_j' + 1}{= \lambda_i . \lambda_j' + 1} \tab if i=j \cr
 #'          \tab \eqn{= \lambda_i .\lambda_j'}{= \lambda_i . \lambda_j'} \tab else, \cr}
 #' this function represents the correlations computed from covariances :
 #'\deqn{R_{ij} = \frac{\Sigma_{ij}}{\sqrt{\Sigma_ii\Sigma _jj}}}{R_ij = Sigma_ij / sqrt(Sigma_ii.Sigma _jj)}.
-#' @author \tabular{l}{
-#' Ghislain Vieilledent <ghislain.vieilledent@cirad.fr>\cr
-#' Jeanne Clément <jeanne.clement16@laposte.net>\cr }
-#' @references \tabular{l}{
-#' Pichler M. and Hartig F. (2020). “A new method for faster and more accurate inference of species associations from big community data”. \cr}
-#' @seealso \code{\link{jSDM-package}} \code{\link{get_residual_cor}} \code{\link{jSDM_binomial_probit}} \code{\link{jSDM_binomial_probit_long_format}} \code{\link{jSDM_binomial_logit}}  \code{\link{jSDM_poisson_log}} 
+#' @author 
+#' 
+#' Ghislain Vieilledent <ghislain.vieilledent@cirad.fr>
+#' 
+#' Jeanne Clément <jeanne.clement16@laposte.net>
+#' @references Pichler M. and Hartig F. (2021) A new method for faster and more accurate inference of species associations from big community data. \cr
+#'             \emph{Methods in Ecology and Evolution}, 12, 2159-2173 (doi:10.1111/2041-210X.13687).
+#' @seealso \code{\link{jSDM-package}} \code{\link{get_residual_cor}} \cr
+#' \code{\link{jSDM_binomial_probit}} \code{\link{jSDM_binomial_probit_long_format}} \cr
+#' \code{\link{jSDM_binomial_probit_sp_constrained}} \code{\link{jSDM_binomial_logit}}  \code{\link{jSDM_poisson_log}} 
 #' @examples 
 #' library(jSDM)
 #' # frogs data
@@ -222,17 +226,21 @@ add_species_arrows = function(radius = 5.0, label = "Species", reverse = TRUE, s
 #' R <- get_residual_cor(mod)$cor.mean
 #' plot_associations(R, circleBreak = TRUE, occ = PA_mites, species_order="abundance")
 #' # Average of MCMC samples of species enrironmental effect beta except the intercept
-#' env_effect <- t(sapply(mod$mcmc.sp,colMeans)[grep("beta_",colnames(mod$mcmc.sp[[1]]))[-1],])
+#' env_effect <- t(sapply(mod$mcmc.sp,
+#'                        colMeans)[grep("beta_", colnames(mod$mcmc.sp[[1]]))[-1],])
 #' colnames(env_effect) <-  gsub("beta_", "", colnames(env_effect))
 #' plot_associations(R, env_effect = env_effect, species_order="main env_effect")
 #' @importFrom graphics polygon text 
 #' @export
 plot_associations = function(R, radius = 5.0, main = NULL, 
                              circleBreak = FALSE, top = 10L, occ = NULL, env_effect=NULL, 
-                             cols_association = c("#FF0000", "#BF003F", "#7F007F", "#3F00BF", "#0000FF"),
-                             cols_occurrence = c( "#BEBEBE", "#8E8E8E", "#5F5F5F", "#2F2F2F", "#000000"),
-                             cols_env_effect =c("#1B9E77", "#D95F02", "#7570B3", "#E7298A",
-                                                "#66A61E", "#E6AB02", "#A6761D", "#666666"),
+                             cols_association = c("#FF0000", "#BF003F", "#7F007F",
+                                                  "#3F00BF", "#0000FF"),
+                             cols_occurrence = c("#BEBEBE", "#8E8E8E", "#5F5F5F",
+                                                 "#2F2F2F", "#000000"),
+                             cols_env_effect = c("#1B9E77", "#D95F02", "#7570B3",
+                                                 "#E7298A", "#66A61E", "#E6AB02",
+                                                 "#A6761D", "#666666"),
                              lwd_occurrence = 1.0,
                              species_order="abundance",
                              species_indices = NULL
