@@ -76,7 +76,7 @@ Rcpp::List  Rcpp_jSDM_poisson_log_traits_lv(
   // Y
   dens_data.Y = Y;
   // T
-  dens_data.T = NA_REAL;
+  dens_data.T = arma::ones<arma::uvec>(NSITE);
   // Suitability process 
   dens_data.NP = NP;
   dens_data.X = X;
@@ -98,11 +98,11 @@ Rcpp::List  Rcpp_jSDM_poisson_log_traits_lv(
   dens_data.V_W = V_W;
   dens_data.W_run = W_start;
   // alpha
-  dens_data.site_alpha = NA_REAL;
-  dens_data.shape = NA_REAL;
-  dens_data.rate = NA_REAL;
-  dens_data.V_alpha_run = NA_REAL;
-  dens_data.alpha_run = NA_REAL;
+  dens_data.site_alpha = 0;
+  dens_data.shape = 0.0;
+  dens_data.rate = 0.0;
+  dens_data.V_alpha_run = 0.0;
+  dens_data.alpha_run = arma::zeros<arma::rowvec>(NSITE);
   
   ////////////////////////////////////////////////////////////
   // Proposal variance and acceptance for adaptive sampling //
